.. _part_bod:

=====================================================
Masses, Inertias & Particles, RigidBodys (Docstrings)
=====================================================

Particle
========

.. automodule:: sympy.physics.mechanics.particle
   :members:


RigidBody
=========

.. automodule:: sympy.physics.mechanics.rigidbody
   :members:


inertia
=======

.. autofunction:: sympy.physics.mechanics.functions.inertia


inertia_of_point_mass
=====================

.. autofunction:: sympy.physics.mechanics.functions.inertia_of_point_mass


linear_momentum
===============

.. autofunction:: sympy.physics.mechanics.functions.linear_momentum


angular_momentum
================

.. autofunction:: sympy.physics.mechanics.functions.angular_momentum

kinetic_energy
==============

.. autofunction:: sympy.physics.mechanics.functions.kinetic_energy

potential_energy
================

.. autofunction:: sympy.physics.mechanics.functions.potential_energy

Lagrangian
==========

.. autofunction:: sympy.physics.mechanics.functions.Lagrangian
